@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014 by Farsight Security, Inc.
+ * Copyright (c) 2014,2019 by Farsight Security, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,7 +29,7 @@ type Input interface {
 	Wait()
 }
 
-// An Output is a desintaion for dnstap data. It accepts data on the channel
+// An Output is a destination for dnstap data. It accepts data on the channel
 // returned from the GetOutputChannel method. The RunOutputLoop() method
 // processes data received on this channel, and returns after the Close()
 // method is called.
@@ -38,3 +38,17 @@ type Output interface {
 	RunOutputLoop()
 	Close()
 }
+
+// A Logger prints a formatted log message to the destination of the
+// implementation's choice. A Logger may be provided for some Input and
+// Output implementations for visibility into their ReadInto() and
+// RunOutputLoop() loops.
+//
+// The result of log.New() satisfies the Logger interface.
+type Logger interface {
+	Printf(format string, v ...interface{})
+}
+
+type nullLogger struct{}
+
+func (n nullLogger) Printf(format string, v ...interface{}) {}
